================
Avocado Releases
================

How we release Avocado
======================

The regular releases are released after each sprint, which usually takes 3
weeks. Regular releases are supported only until the next version is released.

We also understand that there are multiple projects currently depending on the
stability of Avocado and we don't want their work to be disrupted by
incompatibilities nor instabilities in new releases.

Because of that, we have **LTS releases**, that are regular releases
considering the release cycle, but a new branch is created and bugfixes are
backported on demand for a period of about 18 months after the release. Every
year (or so) a new LTS version is released.  Two subsequent LTS versions are
guaranteed to have 6 months of supportability overlap.

Long Term Stability Releases
============================

.. toctree::
   :maxdepth: 1

   lts/82_0
   lts/69_0
   lts/52_0
   lts/next

Regular Releases
================

.. toctree::
   :maxdepth: 1

   86_0
   85_0
   84_0
   83_0
   82_0
   81_0
   80_0
   79_0
   78_0
   77_0
   76_0
   75_1
   75_0
   74_0
   73_0
   72_0
   71_0
   70_0
   69_0
   68_0
   67_0
   66_0
   65_0
   64_0
   63_0
   62_0
   61_0
   60_0
   59_0
   58_0
   57_0
   56_0
   55_0
   54_1
   54_0
   53_0
   52_0
   51_0
   50_0
   49_0
   48_0
   47_0
   46_0
   45_0
   44_0
   43_0
   42_0
   41_0
   40_0
   39_0
   38_0
   37_0
   36_0
   35_0
   0_34_0
   0_33_0
   0_32_0
   0_31_0
   0_30_0
   0_29_0
   0_28_0
   0_27_1
   0_27_0
   0_26_0
   0_25_0
